@@ -32,6 +32,7 @@ from localstack.utils.aws import aws_stack
 from localstack.utils.common import (
     camel_to_snake_case,
     canonical_json,
+    canonicalize_bool_to_str,
     cp_r,
     is_base64,
     keys_to_lower,
@@ -294,7 +295,9 @@ class EventBus(GenericBaseModel):
         return "AWS::Events::EventBus"
 
     def fetch_state(self, stack_name, resources):
-        event_bus_name = self.props.get("Name")
+        event_bus_name = self.resolve_refs_recursively(
+            stack_name, self.props.get("Name"), resources
+        )
         client = aws_stack.connect_to_service("events")
         return client.describe_event_bus(Name=event_bus_name)
 
@@ -314,6 +317,33 @@ class EventBus(GenericBaseModel):
         }
 
 
+class EventConnection(GenericBaseModel):
+    @staticmethod
+    def cloudformation_type():
+        return "AWS::Events::Connection"
+
+    def fetch_state(self, stack_name, resources):
+        client = aws_stack.connect_to_service("events")
+        conn_name = self.resolve_refs_recursively(stack_name, self.props.get("Name"), resources)
+        return client.describe_connection(Name=conn_name)
+
+    def get_cfn_attribute(self, attribute_name):
+        props = self.props
+        if attribute_name in REF_ID_ATTRS:
+            return props.get("Name")
+        if attribute_name == "Arn":
+            return props.get("ConnectionArn")
+        # TODO: handle "SecretArn" attribute
+        return super(EventConnection, self).get_cfn_attribute(attribute_name)
+
+    @classmethod
+    def get_deploy_templates(cls):
+        return {
+            "create": {"function": "create_connection"},
+            "delete": {"function": "delete_connection", "parameters": {"Name": "Name"}},
+        }
+
+
 class LogsLogGroup(GenericBaseModel):
     @staticmethod
     def cloudformation_type():
@@ -1759,11 +1789,11 @@ class SNSTopic(GenericBaseModel):
             tags = params.get("Tags") or []
             topic_name = params.get("TopicName")
             if dedup is not None:
-                attributes["ContentBasedDeduplication"] = dedup
+                attributes["ContentBasedDeduplication"] = canonicalize_bool_to_str(dedup)
             if display_name:
                 attributes["DisplayName"] = display_name
             if fifo_topic is not None:
-                attributes["FifoTopic"] = fifo_topic
+                attributes["FifoTopic"] = canonicalize_bool_to_str(fifo_topic)
             if kms_master_key:
                 attributes["KmsMasterKeyId"] = kms_master_key
             result = {"Name": topic_name, "Attributes": attributes, "Tags": tags}
