@@ -235,7 +235,7 @@ def load_plugins(scope=None):
 def get_docker_image_details(image_name=None):
     image_name = image_name or get_docker_image_to_start()
     try:
-        result = DOCKER_CLIENT.inspect_object(image_name)
+        result = DOCKER_CLIENT.inspect_image(image_name)
     except ContainerException:
         return {}
     result = {
@@ -372,6 +372,9 @@ def canonicalize_api_names(apis=None):
             if a == api:
                 return True
 
+    # TODO: enable recursive lookup - e.g., having service "amplify" depend (via API_DEPENDENCIES)
+    #  on composite "serverless", which should add services "s3", "apigateway", etc...
+
     # resolve composites
     for comp, deps in API_COMPOSITES.items():
         if contains(apis, comp):
