@@ -52,6 +52,7 @@ MUTEX_CLEAN = threading.Lock()
 
 # misc. constants
 TIMESTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S"
+TIMESTAMP_FORMAT_TZ = "%Y-%m-%dT%H:%M:%SZ"
 TIMESTAMP_FORMAT_MICROS = "%Y-%m-%dT%H:%M:%S.%fZ"
 CODEC_HANDLER_UNDERSCORE = "underscore"
 
@@ -658,6 +659,15 @@ def epoch_timestamp():
     return time.time()
 
 
+def parse_timestamp(ts_str: str) -> datetime:
+    for ts_format in [TIMESTAMP_FORMAT, TIMESTAMP_FORMAT_TZ, TIMESTAMP_FORMAT_MICROS]:
+        try:
+            return datetime.strptime(ts_str, ts_format)
+        except ValueError:
+            pass
+    raise Exception("Unable to parse timestamp string with any known formats: %s" % ts_str)
+
+
 def retry(function, retries=3, sleep=1.0, sleep_before=0, **kwargs):
     raise_error = None
     if sleep_before > 0:
@@ -1013,7 +1023,12 @@ def first_char_to_upper(s):
 
 
 def format_number(number, decimals=2):
-    return ("{0:.%sg}" % decimals).format(number)
+    # Note: interestingly, f"{number:.3g}" seems to yield incorrect results in some cases.
+    # The logic below seems to be the most stable/reliable.
+    result = f"{number:.{decimals}f}"
+    if "." in result:
+        result = result.rstrip("0").rstrip(".")
+    return result
 
 
 def is_number(s):
@@ -1754,5 +1769,9 @@ def is_none_or_empty(obj: Union[Optional[str], Optional[list]]) -> bool:
     )
 
 
+def canonicalize_bool_to_str(val: bool) -> str:
+    return "true" if str(val).lower() == "true" else "false"
+
+
 # Code that requires util functions from above
 CACHE_FILE_PATTERN = CACHE_FILE_PATTERN.replace("_random_dir_", short_uid())
